==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Layer/ts/Layer_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation>Nástroje Vstvy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Zobraziť nástroje vrstvy</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Showing all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Locking all layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation>Na začiatku alebo na konci nesmie byť medzera.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translation>Zadajte názov vrstvy.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translation>Zadajte iný názov. Takýto už existuje.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>Údaje vrstvy</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Názov vrstvy:</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Farba:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Hrúbka čiary:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Typ čiary:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Layer/ts/Layer_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+97"/>
        <source>Layer Tools</source>
        <translation>Nástroje Vstvy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation>Zobraziť nástroje vrstvy</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translation>&amp;Vrstva</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Showing all layers</source>
        <translation>Zobrazenie všetkých vrstiev</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hiding all layers</source>
        <translation>Skrytie všetkých vrstiev</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Thawing all layers</source>
        <translation>Rozmraziť všetky vrstvy</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Freezing all layers</source>
        <translation>Zmraziť všetky vrstvy</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Locking all layers</source>
        <translation>Uzamknutie všetkých vrstiev</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unlocking all layers</source>
        <translation>Odomknutie všetkých vrstiev</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+191"/>
        <source>Leading or trailing spaces.</source>
        <translation>Na začiatku alebo na konci nesmie byť medzera.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Layer name is empty.</source>
        <translation>Zadajte názov vrstvy.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Layer already exists.</source>
        <translation>Zadajte iný názov. Takýto už existuje.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translation>Údaje vrstvy</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translation>Názov vrstvy:</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation>Vlastnosti</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Farba:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translation>Hrúbka čiary:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translation>Typ čiary:</translation>
    </message>
</context>
</TS>
